#![cfg_attr(test, feature(test))]
#![cfg_attr(feature = "use_nightly", feature(iter_intersperse))]
#![cfg_attr(
    all(not(feature = "std"), feature = "use_nightly"),
    feature(error_in_core),
    no_std
)]
#![forbid(unsafe_code)]
#![warn(clippy::pedantic)]

extern crate alloc;

#[cfg(not(any(feature = "std", feature = "hashbrown")))]
compile_error!(
    "In order for this crate to work it needs either feature `std` or `hashbrown` enabled"
);

#[cfg(not(any(feature = "std", feature = "use_nightly")))]
compile_error!(
    "In order for this crate to work it needs either feature `use_nightly` (and therefore nightly) or `std` enabled"
);

#[cfg(not(any(feature = "use_nightly", feature = "itertools")))]
compile_error!(
    "In order for this crate to work it needs either feature `use_nightly` (and therefore nightly) or `itertools` enabled"
);

pub mod conf;
pub mod parsing;

use internal_import::{Error, HashMap, IntersperseSource};

mod internal_import {
    #[cfg(feature = "std")]
    extern crate std;

    #[cfg(all(not(feature = "std"), feature = "hashbrown"))]
    pub(crate) use hashbrown::HashMap;
    #[cfg(feature = "std")]
    pub(crate) use std::collections::HashMap;

    #[cfg(not(feature = "std"))]
    pub(crate) use core::error::Error;
    #[cfg(feature = "std")]
    pub(crate) use std::error::Error;

    #[cfg(feature = "use_nightly")]
    pub(crate) use core::iter::Iterator as IntersperseSource;
    #[cfg(all(not(feature = "use_nightly"), feature = "itertools"))]
    pub(crate) use itertools::Itertools as IntersperseSource;
}
